#
# spec file for package sopwith
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sopwith
Version:        2.4.0
Release:        1.1
Summary:        SDL port of the %{name} game
License:        GPL-2.0-or-later
Group:          Amusements/Games/Action/Arcade
URL:            https://github.com/fragglet/sdl-sopwith
Source0:        https://github.com/fragglet/sdl-sopwith/releases/download/sdl-sopwith-%{version}/sdl-sopwith-%{version}.tar.gz
Source1:        %{name}.png
BuildRequires:  SDL2-devel
BuildRequires:  SDL2_gfx-devel
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme

%description
This is a port of the classic computer game "Sopwith" to run on modern
computers and operating systems.

%prep
%setup -q -n sdl-%{name}-%{version}

%build
%configure --docdir=%{_docdir}
%make_build

%install
%make_install
rm -rf %{buildroot}%{_datadir}/doc/sdl-%{name}

cat > %{name}.desktop <<EOF
[Desktop Entry]
Name=Sopwith
Type=Application
Comment=The classic %{name} game
Exec=%{name}
Terminal=false
Icon=%{name}
EOF

desktop-file-install --delete-original \
  --dir %{buildroot}%{_datadir}/applications           \
  --add-category ArcadeGame                            \
  --add-category Game                                  \
  %{name}.desktop

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/72x72/apps/
cp %{SOURCE1} %{buildroot}%{_datadir}/icons/hicolor/72x72/apps/

%files
%license COPYING.md
%doc FAQ.md NEWS.md README.md TODO doc/origdoc.txt
%{_bindir}/%{name}
%{_mandir}/man5/sopwith.cfg.5%{?ext_man}
%{_mandir}/man6/%{name}*
%{_datadir}/applications/*%{name}.desktop
%{_datadir}/icons/hicolor/

%changelog
* Fri Mar 22 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.4.0:
  * There is now an emscripten (web) version, available on the website.
  * It is now possible to make and load custom levels (there is no proper
    level editor available yet though).
  * There are now a number of alternative palettes that can be used that
    simulate different CGA palettes and old monitors (thanks techknight).
  * There are now hotkeys to end or restart the current game (thanks techknight).
  * There is now a -p command line option to specify TCP port number.
  * Sound is now oversampled to reduce sound aliasing (thanks @kmill).
  * Starting level is now synchronized between players at multiplayer start.
  * A bug was fixed with the keybindings menu not working (thanks ranguli, NY00123)
  * An input bug was fixed where a backspace would leave some visual corruption,
    and the cursor now blinks.
  * A bug was fixed where the same medal could be awarded twice.
  * Timing of music on the title screen was fixed (thanks @NY00123).
* Fri Jun 16 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 2.3.0:
  * Medals are no longer cleared after a crash.
  * The purple heart medal is now only awarded to players injured in combat.
  * The close button now quits the game (thanks Will Thompson)
  * The help screen is no longer shown when aborting the game.
- Update to 2.2.0:
  * Help text is now shown for new players. This is shown on game start in
    novice mode, but won't be shown again after a successful flight.
  * It's no longer possible to flip the plane upside down while sitting
    motionless on the runway (a bug since the original DOS versions).
  * It's no longer possible to get wounded on the ground.
  * The game no longer freezes up in multiplayer mode if the other player quits.
  * If the game quits with an error, a friendly dialog box now shows the error.
  * Some minor manpage fixes
  * Lots more internal cleanups
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 2.1.1:
  * An embarrassing bug was fixed where you could win by bombing your own
  buildings.
  * The ox "splat" screen now shows correctly if you are shot down and crash
  into an ox.
  * Bug fixes and changes in this version:
  * libm is included as a dependency when needed (thanks slicer69).
  * No error is printed if the config file doesn't exist (thanks Kenneth
  Pronovici).
  * The screen is now redrawn properly when in menus and the window is
    uncovered
  or resized (thanks Kenneth Pronovici).
  * Some potential crashes were fixed when near the edges of the map.
  * Some of the code has been refactored to centralize how levels are
    defined. In
  the future this will help to support custom levels.
  * Documentation changes:
  * Build instructions were clarified (thanks Kenneth Pronovici).
  * Better documentation of novice mode was added to the manpage (thanks
    Kenneth
  Pronovici).
  * References to the -p argument were removed from the manpage and the help
    text
  (thanks Kenneth Pronovici).
  * Changes in this version:
  * Sound has been reenabled. Sound output is now passed through a bandpass
  filter intended to make it sound like a real PC speaker, and also plays
  back at a much quieter volume, to be less startling to new players.
  * Medals are now awarded to reward players (thanks creichen). The Unix
  manpage includes some details about the medals and how to attain them.
  * There is now a configuration screen for setting key bindings, which are
  stored in the same configuration file as other settings.
  * Thanks to SDL2's renderer API, the game now scales up to arbitrary
    window
  sizes and resolutions, and isn't limited to just 320x200 or 640x400.
  * Network performance has been improved significantly.
  * The Unix manpage has been significantly improved and expanded. A
    separate
  manpage was added for the configuration file.
  * Sopwith now runs on macOS, and Mac .dmg packages are generated.
  * Also now builds and runs cleanly on Haiku.
  * The Windows .exe now has metadata and an icon.
  * The missiles feature was changed to a hidden setting since it's not very
  fun and doesn't really fit the game's theme.
  * The networking option to use a "TCP loop" has now been merged with the
  normal "connect" option, for simplicity. The target server may be a real
  server or a TCP loop server, and the clients will autodiscover.
  * Movement precision within the game was made significantly more precise.
  This fixes a long-standing issue where fractional movement values were
  just being discarded, instead of being included in calculations as they
  should have been.
  * Fix computer planes not shooting when tailing the player's plane
    (creichen).
  * Fix planes crashing into their own bullets (creichen).
  * Fix players able to turn quickly when wounded and using the autopilot.
  * Damaged ground no longer remains on the title screen after the game
    ends.
  * Network games no longer desync when only one player uses harry keys
    mode.
  * Big oil tank explosions now match the magnitude of the old explosions
    from
  Sopwith 1 and Sopwith 2. The command line option to disable them has been
  replaced with a configuration variable.
  * A bug was fixed where it was possible to stop the plane in midair when
  playing the game in novice mode (thanks Alaux).
  * Code has been ported to SDL2.
  * Rewritten graphics code
  * Major internal restructuring: removal of obsolete code, removal of
  some global variables
  * Sopwith configuration file is no longer ~/.sopwithrc on \*nix systems,
    but
  can now be found at ~/.local/share/SDL\ Sopwith/sopwith.cfg
- drop sopwith-fix-string-include.patch, sopwith-gpl.diff: obsolete
* Wed Mar 25 2015 p.drouand@gmail.com
- Update to version 1.8.4
  * Updated man page (doc/sopwith.6) to match Debian's manual page.
  * Bring Sopwith up to date with bug fixes provided by Fedora.
    This should avoid crash on start-up problems and makes
    compiling more robust.
- Changes from version 1.8.3
  * The function asynclos() in swasynio.c includes a parameter
    which is never used. Calling functions do not bother passing
    a parameter. To avoid undefined behaviour the definition of
    aynclos() has been fixed. (bdo#748172)
  * Updated manual page to provide current default keys and
    mention the location of the custom keys file (~/.sopwith/keys)
  * Removed stray object files from tarball.
  * Added rule to makefile "tarball" which performs more
    complete clean-up and makes tarball in parent directory.
- Changes from version 1.8.2
  * Added SDL_CFLAGS flag to src/Makefile to bring us
    in line with FreeBSD patches.
  * Updated copyright notice on help screen.
  * Removed compiler optimiations to avoid crashes when game is
    built using versions of GCC newer than 4.6.
- Changes from version 1.8.1
  * Corrected initialization error would would prevent sound
    from playing at start-up.
  * Updated documentation to include command line flags for
  playing music (-p) and starting Sopwith in quiet mode (-q).
- Changes from version 1.8.0
  * Most distributions are moving to GTK-3, sopwith's legacy code uses
    GTK-2. Dropping GTK support in favour of SDL.
  * Modified configure script.
  * Patched crash caused by failure to find a suitable video device.
  * Modified src/sdl/video.c to add new check.
  * Fixed configure warings related to datarootdir variable.
- Changes from version 1.7.5
  * Cleaned up code to avoid compile warnings. Sopwith now
    builds cleanly using Clang 3.0 and GCC 4.6.
  * Added custom keys option. Controls can be altered by
    adjusting the values in the ~/.sopwith/keys file. On
    Windows this file should be located in the user's profile
    under "AppData/Local/.sopwith/keys".
- Changes from version 1.7.4
  * Added man page patch to update documentation.
  * Added include statements in vid_vga.c and sdl/video.c to bring
    us in line with Debian's patches.
  * Applied patch to swasynio.c to correct spelling errors.
  * Oil tank explosions should be a little more intense now. These
    larger/faster explosions can be turned off at the command line
    by using the "-e" flag. (bdo#188298.)
- Changes from version 1.7.3
  * Added range check patch to avoid crashes when plan or missile
  is close to the edge of the map. (bdo#224518 and bdo#258751)
  * Mouse pointer no longer appears over Sopwith window.
    (bdo#187930)
  * Depreciated gtk branch, updated configure/makefile scripts.
  * Sound is now turned off by default. Sound can be turned on using
    the -p flag from the command line.
  * Fixed socket check in tcpcomm.c (error returns -1, not less than -2).
  * When AI plane is chasing the player's plane, the AI plane will
    now shoot if it is in position. (swauto.c)
  * When the player's plane is damaged, the auto-pilot is less
    manouverable, just like the player's controls. (swauto.c)
  * Holding down the X or Z keys now causes the player's plane to
    constantly speed up or slow down. Previously, the key had
    to be rapidly tapped to change speed. (bdo#188301)
  * Updated title screen to show exit message.
  * Fixed compiler warning in swconf.c
- Changes from version 1.7.2
  * Cleaned up some compile errors from gcc 4.4.1 on Ubuntu.
    (bdo#582399)
  * Added -g command line option. -g and a number, such as -g2
    will start the game on difficulty level 2. Normally the
    game starts at zero. (bdo#582398)
- Correct source Url
- Remove fixed on upstream patches
  * sopwith-gcc4.patch
  * sopwith.6.patch
  * sopwith-gtk-video.patch
  * sopwith-sdl-video.patch
  * sopwith-vid_vga.patch
- Update sopwith-gpl.diff
- Add sopwith-fix-string-include.patch
- Remove gtk2-devel of require list; upstream has dropped gtk support
- Remove redundant %%clean section
* Fri Aug  3 2012 lnussel@suse.de
- use font header file from SDL_gfx (bnc#774330)
* Mon Jul 23 2012 lnussel@suse.de
- initial package version 1.7.1 based on Fedora's
